Core types for browser forensic analysis.
Modules
- analyze
- Browser event analysis utilities.
- sqlite
- Read-only, WAL-safe opening of browser SQLite evidence databases.
- test_
utils - timestamp
Structs
- Browser
Event - A single browser forensic event.
- Forensic
Meta - Forensic metadata from forensicnomicon for a specific browser artifact.
Enums
- Artifact
Kind - Kind of browser artifact.
- Browser
Family - Browser engine family.
- Evidence
Strength - How strongly an artifact proves a fact in isolation.
Functions
- detect_
browser - Detect the browser family from a file path.