pub fn detect_browser(path: &Path) -> Option<BrowserFamily>Expand description
Detect the browser family from a file path.
Returns None if the path does not match a known browser artifact.
pub fn detect_browser(path: &Path) -> Option<BrowserFamily>Detect the browser family from a file path.
Returns None if the path does not match a known browser artifact.